@@ -2,7 +2,7 @@
 
 # MIT License
 
-# Copyright (c) 2019, Marco Marzetti <marco@lamehost.it>
+# Copyright (c) 2022, Marco Marzetti <marco@lamehost.it>
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -11,8 +11,8 @@
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
 
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -30,11 +30,36 @@ Provides CLI interface for package aggregate-prefixes
 import argparse
 import logging
 import sys
+from typing import Union
+from ipaddress import IPv4Network, IPv6Network
 
 from aggregate_prefixes import aggregate_prefixes
 from .__about__ import __version__ as VERSION
 
 
+def strip_host_mask(prefix: Union[IPv4Network, IPv6Network]) -> str:
+    """
+    Prefix formatting function.
+    Removes netmask if prefix is a host route (/32 IPv4 or /128 IPv6)
+
+    Arguments:
+    ----------
+    prefix: Union[IPv4Network, IPv6Network]
+        Prefix to be formatted
+
+    Returns:
+    --------
+    str: Formatted prefix
+    """
+    if (
+        (prefix.version == 4 and prefix.prefixlen == 32) or
+        (prefix.version == 6 and prefix.prefixlen == 128)
+    ):
+        return str(prefix.network_address)
+
+    return str(prefix)
+
+
 def main() -> None:
     """
     Aggregates IPv4 or IPv6 prefixes from file or STDIN.
@@ -51,7 +76,7 @@ def main() -> None:
         'prefixes',
         type=argparse.FileType('r'),
         nargs='?',
-        help='Text file of unsorted list of IPv4 or IPv6 prefixes. Use \'-\' for STDIN.',
+        help='Text file of unsorted list of IPv4 or IPv6 prefixes. Use \'-\' for STDIN.',  # noqa
         default=sys.stdin
     )
     parser.add_argument(
@@ -61,12 +86,19 @@ def main() -> None:
         help='Discard longer prefixes prior to processing',
         default=128
     )
+    parser.add_argument(
+        '--strip-host-mask', '-s',
+        dest='strip_host_mask',
+        help="Do not print netmask if prefix is a host route (/32 IPv4, /128 IPv6)",  # noqa
+        action='store_true',
+        default=False
+    )
     parser.add_argument(
         '--truncate', '-t',
         metavar='MASK',
         type=int,
         help='Truncate IP/mask to network/mask',
-        default=128
+        default=False
     )
     parser.add_argument(
         '--verbose', '-v',
@@ -96,13 +128,23 @@ def main() -> None:
 
     try:
         # Aggregate
-        aggregates = aggregate_prefixes(prefixes, args.max_length, args.truncate)
+        aggregates = aggregate_prefixes(
+            prefixes,
+            args.max_length,
+            args.truncate
+        )
     except (ValueError, TypeError) as error:
         sys.exit(f'ERROR: {error}')
 
-    # Cast aggregates to `str` and print one per line
+    # Define output formatting function
+    if args.strip_host_mask:
+        formatting_function = strip_host_mask
+    else:
+        formatting_function = str
+
+    # Process aggregates and print one per line
     print(
-        '\n'.join(map(str, aggregates))
+        '\n'.join(map(formatting_function, aggregates))
     )
 
 
